
#include "config.h"
#include <windows.h>

int _gl_win32_winnt = _WIN32_WINNT; /* the value Gnulib was built with */

#define USE_CRIT 1

static CONSOLE_SCREEN_BUFFER_INFO console_info;
static HANDLE                     stdout_hnd;

#if USE_CRIT
  static CRITICAL_SECTION g_trace_crit;
#endif

int _gl_trace_level (void)
{
  static int dbg_level = -1;
  const char *env;

  if (dbg_level >= 0)   /* Already done this, get out */
     return (dbg_level);

  env = getenv ("GL_TRACE");
  dbg_level = env ? (*env-'0') : 0;

  stdout_hnd = GetStdHandle (STD_OUTPUT_HANDLE);
  GetConsoleScreenBufferInfo (stdout_hnd, &console_info);
#if USE_CRIT
  InitializeCriticalSection (&g_trace_crit);
#endif
  return (dbg_level);
}

void _gl_trace_color (unsigned short col)
{
  fflush (stdout);

  /* Restore to "default" colour
   */
  if (col == 0)
  {
    SetConsoleTextAttribute (stdout_hnd, console_info.wAttributes);
#if USE_CRIT
    LeaveCriticalSection (&g_trace_crit);
#endif
  }
  else
  {
#if USE_CRIT
    if (col == GL_TRACE_COLOR_START)
       EnterCriticalSection (&g_trace_crit);
#endif
    SetConsoleTextAttribute (stdout_hnd, (console_info.wAttributes & ~7) | col);
  }
}
